# -*- coding: utf-8 -*-

import os, sys
# ensure citruleaf.py is in path
sys.path.insert(1, os.path.realpath( os.pardir ) )

import unittest
import citrusleaf as cl

class TestChangePassword(unittest.TestCase):

    @classmethod
    def setUpClass(cls):
        
        cls.cluster_with_user_admin = cl.CitrusleafCluster()
        cls.cluster_with_user_admin.setUser('testuauser', cl.hashpassword('aerospike'))
        cl.cluster_setHost(cls.cluster_with_user_admin, 'localhost', '3000')

        cls.cluster_with_read_user = cl.CitrusleafCluster()
        cls.cluster_with_read_user.setUser('testreaduser', cl.hashpassword('aerospike'))
        cl.cluster_setHost(cls.cluster_with_read_user, 'localhost', '3000')
    
    @classmethod
    def tearDownClass(cls):

        del(cls.cluster_with_user_admin)
        del(cls.cluster_with_read_user)

    def test_changePassword(self):

        status = cl.changePassword(TestChangePassword.cluster_with_user_admin, 'testsauser', cl.hashpassword('aerospike'), cl.hashpassword('p@ssword'))

        self.assertEqual(0, status)
 
        status = cl.changePassword(TestChangePassword.cluster_with_user_admin, 'testsauser', cl.hashpassword('p@ssword'), cl.hashpassword('aerospike'))

        self.assertEqual(0, status)

    def test_changePassword_for_wrong_old_password(self):

        status = cl.changePassword(TestChangePassword.cluster_with_user_admin, 'testsauser', cl.hashpassword('asd'), cl.hashpassword('p@ssword'))

        self.assertEqual(62, status)

    def test_changePassword_for_same_old_and_new_passwords(self):

        status = cl.changePassword(TestChangePassword.cluster_with_user_admin, 'testsauser', cl.hashpassword('aerospike'), cl.hashpassword('aerospike'))

        self.assertEqual(0, status)

    def test_changePassword_with_other_than_useradmin_user(self):

        status = cl.changePassword(TestChangePassword.cluster_with_read_user, 'testsauser', cl.hashpassword('aerospike'), cl.hashpassword('aerospike'))

        self.assertEqual(0, status)

if __name__ == "__main__":
    unittest.main()
